@@ -19,16 +19,16 @@ class XRaySettingsConfigParser:
     def __init__(self, settings):
         if "XRAY" in settings:
             xray = settings["XRAY"]
-            self.enabled = xray.get("ENABLED", False)
+            self.enabled = xray.getboolean("ENABLED", False)
             self.service_name = xray.get("SERVICE_NAME")
             self.plugins = xray.get("PLUGINS", "'ECSPlugin', 'EC2Plugin'")
-            self.sampling = xray.get("SAMPLING", False)
-            self.stream_sql = xray.get("STREAM_SQL", True)
+            self.sampling = xray.getboolean("SAMPLING", False)
+            self.stream_sql = xray.getboolean("STREAM_SQL", True)
             self.daemon = xray.get("DAEMON", "xray-daemon:2000")
             self.patch_modules = xray.get("PATCH_MODULES", None)
-            self.logging_enabled = xray.get("LOGGING_ENABLED", False)
-            self.sqlalchemy = xray.get("SQLALCHEMY", False)
-            self.middleware = xray.get("MIDDLEWARE", True)
+            self.logging_enabled = xray.getboolean("LOGGING_ENABLED", False)
+            self.sqlalchemy = xray.getboolean("SQLALCHEMY", False)
+            self.middleware = xray.getboolean("MIDDLEWARE", True)
         else:
             self.enabled = False
             self.service_name = None
@@ -151,4 +151,8 @@ def xray_task_failure(einfo, **kwargs):
         return
     if einfo:
         stack = stacktrace.get_stacktrace(limit=xray_recorder.max_trace_back)
-        segment.add_exception(einfo.exception, stack)
+        try:
+            segment.add_exception(einfo.exception, stack)
+        except FileNotFoundError as e:  # os.getcwd() crashes sometimes we need to handle this issue
+            logging.info("File not found error whne segment.add_exception")
+
